@@ -139,7 +139,7 @@ class BestEffortCallback(CallbackBase):
         if self._heading_enabled:
             print("Transient Scan ID: {0}     Time: {1}".format(
                 self._start_doc['scan_id'],
-                time.strftime("%Y/%m/%d %H:%M:%S", tt)))
+                time.strftime("%Y-%m-%d %H:%M:%S", tt)))
             print("Persistent Unique Scan ID: '{0}'".format(
                 self._start_doc['uid']))
 
@@ -215,7 +215,7 @@ class BestEffortCallback(CallbackBase):
             # If any open figure matches 'figname {number}', use it. If there
             # are multiple, the most recently touched one will be used.
             pat1 = re.compile('^' + fig_name + '$')
-            pat2 = re.compile('^' + fig_name + ' \d+$')
+            pat2 = re.compile('^' + fig_name + r' \d+$')
             for label in plt.get_figlabels():
                 if pat1.match(label) or pat2.match(label):
                     fig_name = label
@@ -265,7 +265,7 @@ class BestEffortCallback(CallbackBase):
             x_key, = dim_fields
             for y_key, ax in zip(columns, axes):
                 dtype = doc['data_keys'][y_key]['dtype']
-                if dtype not in ('number',):
+                if dtype not in ('number', 'integer'):
                     warn("Omitting {} from plot because dtype is {}"
                          "".format(y_key, dtype))
                     continue
