@@ -1,6 +1,4 @@
 from collections import ChainMap
-import matplotlib.pyplot as plt
-import matplotlib.colors as mcolors
 from cycler import cycler
 import numpy as np
 import warnings
@@ -49,6 +47,7 @@ class LivePlot(CallbackBase):
     """
     def __init__(self, y, x=None, *, legend_keys=None, xlim=None, ylim=None,
                  ax=None, fig=None, epoch='run', **kwargs):
+        import matplotlib.pyplot as plt
         super().__init__()
         if fig is not None:
             if ax is not None:
@@ -94,8 +93,13 @@ class LivePlot(CallbackBase):
         kwargs = ChainMap(self.kwargs, {'label': label})
         self.current_line, = self.ax.plot([], [], **kwargs)
         self.lines.append(self.current_line)
-        self.legend = self.ax.legend(
-            loc=0, title=self.legend_title).draggable()
+        legend = self.ax.legend(loc=0, title=self.legend_title)
+        try:
+            # matplotlib v3.x
+            self.legend = legend.set_draggable(True)
+        except AttributeError:
+            # matplotlib v2.x (warns in 3.x)
+            self.legend = legend.draggable(True)
         super().start(doc)
 
     def event(self, doc):
@@ -156,7 +160,7 @@ class LiveScatter(CallbackBase):
     """Plot scattered 2D data in a "heat map".
 
     Alternatively, if the data is placed on a regular grid, you can use
-    :func:`bluesky.callbacks.LiveGrid`.
+    :func:`bluesky.callbacks.mpl_plotting.LiveGrid`.
 
     This simply wraps around a `PathCollection` as generated by scatter.
 
@@ -181,10 +185,12 @@ class LiveScatter(CallbackBase):
 
     See Also
     --------
-    :class:`bluesky.callbacks.LiveGrid`.
+    :class:`bluesky.callbacks.mpl_plotting.LiveGrid`.
     """
     def __init__(self, x, y, I, *, xlim=None, ylim=None,
                  clim=None, cmap='viridis', ax=None, **kwargs):
+        import matplotlib.pyplot as plt
+        import matplotlib.colors as mcolors
         if ax is None:
             fig, ax = plt.subplots()
             fig.show()
@@ -280,7 +286,7 @@ class LiveGrid(CallbackBase):
     pixel to fill in.
 
     For non-gridded data with arbitrary placement, use
-    :func:`bluesky.callbacks.LiveScatter`.
+    :func:`bluesky.callbacks.mpl_plotting.LiveScatter`.
 
     This simply wraps around a `AxesImage`.
 
@@ -320,12 +326,14 @@ class LiveGrid(CallbackBase):
 
     See Also
     --------
-    :class:`bluesky.callbacks.LiveScatter`.
+    :class:`bluesky.callbacks.mpl_plotting.LiveScatter`.
     """
     def __init__(self, raster_shape, I, *,
                  clim=None, cmap='viridis',
                  xlabel='x', ylabel='y', extent=None, aspect='equal',
                  ax=None, x_positive='right', y_positive='up'):
+        import matplotlib.pyplot as plt
+        import matplotlib.colors as mcolors
         if ax is None:
             fig, ax = plt.subplots()
         ax.cla()
@@ -363,7 +371,7 @@ class LiveGrid(CallbackBase):
 
         # make sure the 'positive direction' of the axes matches what is defined in
         #axes_positive
-        xmin, xmax = self.ax.get_ylim()
+        xmin, xmax = self.ax.get_xlim()
         if ((xmin > xmax and self.x_positive == 'right') or
                 (xmax > xmin and self.x_positive == 'left')):
             self.ax.set_xlim(xmax, xmin)
@@ -532,6 +540,7 @@ def plot_peak_stats(peak_stats, ax=None):
     arts : dict
         dictionary of matplotlib Artist objects, for further styling
     """
+    import matplotlib.pyplot as plt
     arts = {}
     ps = peak_stats  # for brevity
     if ax is None:
