@@ -92,6 +92,10 @@ _call_sig = Signature(
      Parameter('metadata_kw', Parameter.VAR_KEYWORD)])
 
 
+def default_scan_id_source(md):
+    return md.get('scan_id', 0) + 1
+
+
 class RunEngine:
     """The Run Engine execute messages and emits Documents.
 
@@ -132,6 +136,13 @@ class RunEngine:
         completely up to the user. The function's return value is
         ignored.
 
+    scan_id_source : callable, optional
+        a function that will be used to calculate scan_id. Default is to
+        increment scan_id by 1 each time. However you could pass in a
+        customized function to get a scan_id from any source.
+        Expected signature: f(md)
+        Expected return: updated scan_id value
+
     Attributes
     ----------
     md
@@ -203,17 +214,16 @@ class RunEngine:
                              'remove_suspender']
 
     def __init__(self, md=None, *, loop=None, preprocessors=None,
-                 context_managers=None, md_validator=None):
+                 context_managers=None, md_validator=None,
+                 scan_id_source=default_scan_id_source):
         if loop is None:
             loop = asyncio.get_event_loop()
         self._loop = loop
 
         # Make a logger for this specific RE instance, using the instance's
         # Python id, to keep from mixing output from separate instances.
-        logger_name = "{name}_id{id}".format(name=__name__, id=id(self))
+        logger_name = "bluesky.RE.{id}".format(id=id(self))
         self.log = logging.getLogger(logger_name)
-        self.log.setLevel(logging.DEBUG)
-        self.verbose = False  # a convenience property, setting log.disabled
 
         if md is None:
             md = {}
@@ -227,6 +237,7 @@ class RunEngine:
         if md_validator is None:
             md_validator = _default_md_validator
         self.md_validator = md_validator
+        self.scan_id_source = scan_id_source
 
         self.max_depth = None
         self.msg_hook = None
@@ -729,6 +740,7 @@ class RunEngine:
             for mgr in self.context_managers:
                 stack.enter_context(mgr(self))
             self._task = self.loop.create_task(self._run())
+            self.log.info("Executing plan %r", self._plan)
             try:
                 self.loop.run_forever()
             finally:
@@ -1062,8 +1074,8 @@ class RunEngine:
             else:
                 try:
                     stop(success=success)
-                except Exception as exc:
-                    self.log.error("Failed to stop %r. Error: %r", obj, exc)
+                except Exception:
+                    self.log.exception("Failed to stop %r.", obj)
 
     @asyncio.coroutine
     def _run(self):
@@ -1076,6 +1088,7 @@ class RunEngine:
         - Try to remove any monitoring subscriptions left on by the plan.
         - If interrupting the middle of a run, try to emit a RunStop document.
         """
+        debug = logging.getLogger('{}.msg'.format(self.log.name)).debug
         pending_cancel_exception = None
         self._reason = ''
         # sentinel to decide if need to add to the response stack or not
@@ -1168,6 +1181,7 @@ class RunEngine:
                     # if we have a message hook, call it
                     if self.msg_hook is not None:
                         self.msg_hook(msg)
+                    debug(msg)
 
                     # update the running set of all objects we have seen
                     self._objs_seen.add(msg.obj)
@@ -1243,13 +1257,11 @@ class RunEngine:
             self._exit_status = 'abort'
             # TODO Is the sleep here necessary?
             yield from asyncio.sleep(0, loop=self.loop)
-            self.log.error("Run aborted")
-            self.log.error("%r", self._exception)
+            self.log.exception("Run aborted")
         except Exception as err:
             self._exit_status = 'fail'  # Exception raises during 'running'
             self._reason = str(err)
-            self.log.error("Run aborted")
-            self.log.error("%r", err)
+            self.log.exception("Run aborted")
             raise err
         finally:
             # Some done_callbacks may still be alive in other threads.
@@ -1262,22 +1274,21 @@ class RunEngine:
             for obj in list(self._uncollected):
                 try:
                     yield from self._collect(Msg('collect', obj))
-                except Exception as exc:
-                    self.log.error("Failed to collect %r. Error: %r", obj, exc)
+                except Exception:
+                    self.log.exception("Failed to collect %r.", obj)
             # in case we were interrupted between 'stage' and 'unstage'
             for obj in list(self._staged):
                 try:
                     obj.unstage()
-                except Exception as exc:
-                    self.log.error("Failed to unstage %r. Error: %r", obj, exc)
+                except Exception:
+                    self.log.exception("Failed to unstage %r.", obj)
                 self._staged.remove(obj)
             # Clear any uncleared monitoring callbacks.
             for obj, (cb, kwargs) in list(self._monitor_params.items()):
                 try:
                     obj.clear_sub(cb)
-                except Exception as exc:
-                    self.log.error("Failed to stop monitoring %r. Error: %r",
-                                   obj, exc)
+                except Exception:
+                    self.log.exception("Failed to stop monitoring %r.", obj)
                 else:
                     del self._monitor_params[obj]
             sys.stdout.flush()
@@ -1285,9 +1296,9 @@ class RunEngine:
             if self._run_is_open:
                 try:
                     yield from self._close_run(Msg('close_run'))
-                except Exception as exc:
-                    self.log.error("Failed to close run %r. Error: %r",
-                                   self._run_start_uid, exc)
+                except Exception:
+                    self.log.error(
+                        "Failed to close run %r.", self._run_start_uid)
 
             for p in self._plan_stack:
                 try:
@@ -1301,6 +1312,7 @@ class RunEngine:
         # if the task was cancelled
         if pending_cancel_exception is not None:
             raise pending_cancel_exception
+        self.log.info("Cleaned up from plan %r", self._plan)
 
     @asyncio.coroutine
     def _wait_for(self, msg):
@@ -1339,11 +1351,9 @@ class RunEngine:
         self._clear_run_cache()
         self._run_start_uid = new_uid()
         self._run_start_uids.append(self._run_start_uid)
-        self.log.debug("Starting new with uid %r", self._run_start_uid)
 
-        # Increment scan ID
-        scan_id = self.md.get('scan_id', 0) + 1
-        self.md['scan_id'] = scan_id
+        # Run scan_id calculation method
+        self.md['scan_id'] = self.scan_id_source(self.md)
 
         # For metadata below, info about plan passed to self.__call__ for.
         plan_type = type(self._plan).__name__
@@ -1404,7 +1414,7 @@ class RunEngine:
         num_events = {}
         for bundle_name, counter in self._sequence_counters.items():
             if bundle_name is None:
-                # rare but possible via Msg('create')
+                # rare but possible via Msg('create', name='primary')
                 continue
             num_events[bundle_name] = next(counter) - 1
         reason = msg.kwargs.get('reason', None)
@@ -1432,7 +1442,7 @@ class RunEngine:
         Expected message object is:
 
             Msg('create', None, name='primary')
-            Msg('create')
+            Msg('create', name='primary')
 
         Note that the `name` kwarg will be the 'name' field of the resulting
         descriptor. So descriptor['name'] = msg.kwargs['name'].
@@ -1453,13 +1463,16 @@ class RunEngine:
         self._asset_docs_cache.clear()
         self._objs_read.clear()
         self._bundling = True
-        self._bundle_name = None  # default
         command, obj, args, kwargs = msg
         try:
             self._bundle_name = kwargs['name']
         except KeyError:
-            if len(args) == 1:
+            try:
                 self._bundle_name, = args
+            except ValueError:
+                raise ValueError(
+                    "Msg('create') now requires a stream name, given as "
+                    "Msg('create', name) or Msg('create', name=name)") from None
 
     @asyncio.coroutine
     def _read(self, msg):
